<?php
/**
 * config.php
 *
 * contient toutes les options de configuration, il est inclus dans presque tous les scripts
 * car les valeurs des variables qu'ils contient doivent tre disponibles pour la plupart des scripts
 * Il est gnr automatiquement lors de l'installation
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package	IEW
 * @author	Sylvain GODM <sylvain.godme@gmail.com>
 * @version	gnr  l'installation, le Vendredi 21 Novembre 2014  10:48:36
 * @copyright	2004-2014 Sylvain GODM
 * @link	http://iew.free.fr
 * @license	GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

if (!defined('SESSION_NAME')) {
 	/**
 	 * Constante contenant le nom de la session PHP (nom du cookie stock sur le navigateur du client)
 	 */	
	define('SESSION_NAME','IEW');
}

/********************** Racine du site ********************************/

if (!defined('IEW_DIR')) {
 	/**
 	 * Constante contenant le chemin complet du rpertoire d'installation IEW
 	 */	
	define('IEW_DIR',realpath(dirname(__FILE__).'/../').'/');
}

// Variable contenant l'Alias d'apache qui permet d'accder  la racine de l'application IEW
//  adapter en cas de modification de l'Alias dfini dans IEW_DIR/install/conf-scribe/apache-iew.conf
// Elle est utilise par de nombreux liens absolus
$racine = "/iew/"; // doit imprativement se terminer par un slash !!

// On a besoin de ceci pour la fonction verif_authdir_data invoque plus loin dans ce script
require_once(IEW_DIR.'lib/fonctions_diverses.php');

// et aussi pour la fonction affiche_erreurs :
require_once(IEW_DIR.'lib/fonctions_erreurs.php');


/**************************** Informations de version *********************************************************/
// Laisser ce copyright SVP
$copyright = "Copyright &copy; 2004-".date("Y")." - Sylvain GODM - Tous droits rservs -<br />IntraEduWeb version ".trim(file_get_contents(IEW_DIR.'VERSION'));

//URL Site officiel IntraEduWeb
$url_site_intraEduWeb = "http://iew.free.fr";

/*************************** Paramtrage des sessions **************************************/
// temps d'inactivit en secondes au bout duquel les utilisateurs authentifis devront se reconnecter
$session_timeout = "3000";

/********************** Paramtres d'authentification ******************************************************/
/**

La procdure d'authentification se droule comme suit :
1 => on tente une authentification SSO (si configur et si l'utilisateur clique sur le lien correspondant dans le formulaire de connexion : variable $auth_method = "cas" ou "lemonldap" 
2 => on tente une authentification sur un serveur LDAP (si configur : variable $auth_method = "ldap")
3 => on tente une authentification locale (native) dans la base utilisateurs IEW (table login)

Si variable $auth_method = "native", seule la tentative n3 sera excute

En authentification SSO ou LDAP, un annuaire LDAP est consult : il est important de connatre sa structure
pour rcuprer les bons attributs, et notamment de connatre le gidNumber d'un individu, pour savoir s'il appartient au groupe des professeurs
ou au groupe des lves par exemple...

**/
$auth_method = "cas";
$sso = "eolesso"; //  dcommenter si l'authentification se fait par CAS eole


%if(%%eolesso_ldap[0] in ("localhost","127.0.0.1"))
$ldap_server_name = "%%adresse_ip_ldap";
%else
$ldap_server_name = "%%eolesso_ldap[0]";
%end if
$ldap_server_port = "%%eolesso_ldap[0].eolesso_port_ldap";
$ldap_base_dn = "%%eolesso_ldap[0].eolesso_base_ldap";
$ldap_user_login_attribute = "uid"; // nom de l'Attribut LDAP contenant l'identifiant de connexion
$ldap_user_eleve_attribute = "gidnumber"; // nom de l'Attribut LDAP qui si prsent dans le dn, permet d'identifier un utilisateur comme tant un lve (on prend pour cela un attribut obligatoire du schma LDAP de l'annuaire ENT)
$ldap_user_eleve_attribute_value = "10002"; // nom de l'Attribut LDAP qui si prsent dans le dn, permet d'identifier un utilisateur comme tant un lve (on prend pour cela un attribut obligatoire du schma LDAP de l'annuaire ENT)
$ldap_user_prof_attribute = "gidnumber"; // nom de l'Attribut LDAP qui si prsent dans le dn, permet d'identifier un utilisateur comme tant un professeur (on prend pour cela un attribut obligatoire du schma LDAP de l'annuaire ENT)
$ldap_user_prof_attribute_value = "10001"; // valeur de l'Attribut LDAP qui si prsent dans le dn, permet d'identifier un utilisateur comme tant un professeur (on prend pour cela un attribut obligatoire du schma LDAP de l'annuaire ENT)
$ldap_cle_jointure = "intid"; // nom de l'Attribut LDAP contenant la cl de jointure entre les donnes du SI MENESR et les donnes d'annuaire ENT ou LDAP

$cas_server_name = "%%eolesso_adresse";
$cas_server_port = "%%eolesso_port";

$validite_mdp = 9; // c'est le nombre de mois pendant lesquels le mot de passe d'un utilisateur reste valide
$timeout_desactivation_mdp = 60; // c'est le nombre de jours prcdent la date limite de validit du mot de passe pendant lesquels l'utilisateur est averti qu'il doit modifier son mot de passe avant que l'accs au systme ne soit bloqu

/********************** Paramtres Serveur MySQL ******************************************************/
// Ces informations seront prcises dans le fichier inc_connect.php


/********************** Interface graphique : les thmes et les couleurs ****************************/
// c'est le rpertoire contenant les squelettes et les feuilles de style par dfaut
$repertoire_theme = "themes/defaut/";
// Squelette par dfaut utilis pour afficher les pages
$squelette = "principal.php";
// rpertoire contenant les lments de navigation
$repertoire_navigation = "navigation/defaut/";
require_once(IEW_DIR.$repertoire_theme."couleurs.php");
// Dominante de couleur utilise pour l'interface graphique
if (isset($_SESSION['anscol']) && $_SESSION['anscol'] !="") // Si on est dans les archives
  $jeu_couleurs = $couleur_dominante["archives"];
else
  $jeu_couleurs = $couleur_dominante["jaune"];

/********************* Paramtres linguistiques ********************************************/
// Langue par dfaut (utilise pour l'instant seulement pour le format d'affichage de la date)
$default_language = "fr";


/********************** Messagerie interne **************************************/
//(vers l'interface de messagerie web seulement)
$url_mail_server = "";
// Contient le nom d'hte du serveur de messagerie (aprs le @ dans les adresses email)
$mail_server = "";
// le protocole utilis
$mail_protocol = ":/";

/***************** Emplacement de donnes stockes sous forme de fichiers *******************************/
// Dossier de stockage des donnes sous forme fichier
// il comprend :
// - En mode d'authentification native seulement : les fichiers textes contenant les identifiants et mots de passe des utilisateurs - ces derniers sont crypts -
// - les fichiers joints aux cahiers de textes
// - les trombinoscopes (fichiers jpg ou png)
// - les fichiers de config ncessaires  IEW
// Seul l'utilisateur apache a le droit d'y crire
// Ce dossier doit tre cr par root sur la machine hbergeante avec un chown -R utilisateur_apache et un chmod -R 0755 sur ce rpertoire
// ceci est un chemin absolu sur la machine hbergeante (doit se terminer par un slash !!)

if (isset($_SESSION['anscol']) && $_SESSION['anscol'] !="") // Si on est dans les archives, ce dossier est dfini en fonction de l'anne scolaire consulte
  $anscol = "data_".$_SESSION['anscol'];
else // sinon, c'est le dossier de stockage classique
  $anscol = "";
if ($anscol == "")
{
  if (substr("/home/www-data/var/www/html/iew/",-5,5)!="data/")
   $stock_baselev = "/home/www-data/var/www/html/iew/"."data/";
  else
   $stock_baselev = "/home/www-data/var/www/html/iew/";
}
else
{
  if (substr("/home/www-data/var/www/html/iew/",-5,5)!="data/")
   $stock_baselev = "/home/www-data/var/www/html/iew/"."data/".$anscol."/";
  else
   $stock_baselev = "/home/www-data/var/www/html/iew/".$anscol."/";
}

// On vrifie l'existence et les droits d'accs au dossier de stockage des fichiers spciaux s'il est dfini
if ($stock_baselev !="") 
{
  $err = verif_authdir_data($stock_baselev);
  if ($err!="")
  {
    $error_message = array($err,"");  
    affiche_erreurs($error_message);
    exit;
  }
}

/**************************** Ressources externes *******************************/
// Si disponible, URL de l'application GRR installe
// si http:// non prcis, c'est relatif  $DOCUMENT_ROOT (doit se terminer par un slash !!) ou bien mettre un Alias apache
$url_grr = "";

// Si disponible, URL de l'application web de gestion des notes (gepi, pronote -logiciel propritaire = beurk-,...)
$url_notation = "";

// Si disponible, URL de l'application web de gestion documentaire (PMB, BCDI,...)
$url_gestdoc = "";

// Si disponible, URL de l'application web de gestion du b2i (gibii,...)
$url_gestb2i = "";

/************************** Informations sur l'tablissement ********************************/
// nom Etablissement

$type_etablissement = "%%nature_etab";
$nom_etablissement = "%%libelle_etab";
$adresse_etablissement = "%%adresse_postale";
$cp_etablissement = "%%code_postal";
$ville_etablissement = "%%ville";
$tel_etablissement = "";
$fax_etablissement = "";
$email_etablissement = "";

// Responsables de publication
// C'est le directeur de l'tablissement

$nom_directeur_publication = "Chef ETAB";
$email_directeur_publication = "";

// URL du site internet de l'tablissement
$url_site_etablissement = "";

// Administrateur IntraEduWeb
$admin_name = "Admin ";
$admin_email = "";
// en fait ici on va passer par un formulaire de saisie avec un champ password puis le script de config crira directement et sous forme crypte ce mot de passe dans la base de donnes mysql (table login)
$admin_passwd = "";

// Le message personnalis de pied de page
$message_pied_page = "";

// Les jours de la ouvrables de la semaine (necessite que le language par defaut soit fr)
$jours_ouvrables = array('Lundi','Mardi','Mercredi','Jeudi','Vendredi','Samedi');

/************** A DEPLACER VERS LES REPERTOIRES DES THEMES POUR L'INTERFACE GRAPHIQUE *****************/
// Concepteur graphique des pages
include(IEW_DIR."themes/defaut/"."designer.php");

// Pas de balise de fin de code php car sinon envoi un message d'erreur : header already sent sur la prochaine intruction session_start()
